@@ -8,19 +8,23 @@ const QString ARG_CAL_NAME = "--calendar";
 const QString ARG_FILE_NAME = "--file";
 const QString ARG_CLEAR = "--clear";
 const QString ARG_VERIFY = "--verify";
+const QString ARG_ALARMS = "--alarms";
+const QString ARG_DAYS = "--days";
 
 //command-line argument strings
 const QString ARG_OP_VAL_IMPORT = "import";
 const QString ARG_OP_VAL_EXPORT = "export";
 const QString ARG_OP_VAL_LIST = "list";
 const QString ARG_OP_VAL_TASKS_CLEAR_DONE = "tasks-clear-done";
+const QString ARG_OP_VAL_TASKS_BUMP_DAY = "tasks-bump-today";
 
 enum operationType {
     OPERATION_UNKNOWN = 0,
     OPERATION_IMPORT,
     OPERATION_EXPORT,
     OPERATION_LIST,
-    OPERATION_TASKS_CLEAR_DONE
+    OPERATION_TASKS_CLEAR_DONE,
+    OPERATION_TASKS_BUMP_DAY
 };
 
 void print_cals(CMulticalendar&);
@@ -32,15 +36,19 @@ bool parse_cmd_arg(const QStringList args, const QString arg);
 bool parse_cmd_arg(const QStringList args, const QString arg, int& pos);
 bool parse_cmd_arg(const QStringList args, const QString arg, QString& value);
 
+bool parse_cmd_arg_days(const QStringList args, int & days);
+
 bool do_operation(const QStringList args, const QString operation);
 bool do_operation_list();
 bool do_operation_import(const QStringList args);
 bool do_operation_export(const QStringList args);
 bool do_operation_tasks_clear_done(const QStringList args);
+bool do_operation_tasks_bump_today(const QStringList args);
 
 void usage_import();
 void usage_export();
 void usage_tasks_clear_done();
+void usage_tasks_bump_day();
 
 #endif // FUNCTIONS_H
 
