@@ -39,10 +39,11 @@ int main(int argc, char *argv[])
         cout << "--operation export" << endl;
         cout << "--operation list" << endl;
         cout << "--operation tasks-clear-done" << endl;
+        cout << "--operation tasks-bump-today" << endl;
 
         return -1;
     }
-    cout << "operation is:" << operation.toLocal8Bit().constData() << endl;
+    //cout << "operation is:" << operation.toLocal8Bit().constData() << endl;
     ok = do_operation(args, operation);
 
     if (!ok){
